BarcodeBar class

Rectangle drawing operation

Inheritance

Constructors

BarcodeBar({required double left, required double top, required double width, required double height, required bool black})
Create a rectangle drawing operation to draw a white or black unit
const

Properties

black → bool
Black or white color of this rectangle
final
bottom → double
bottom position of this element
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
height of this element
finalinherited
left → double
left position of this element
finalinherited
right position of this element
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
top position of this element
finalinherited
width → double
width of this element
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited