BorderRadiusDirectional.horizontal constructor

const BorderRadiusDirectional.horizontal({
  1. Radius start = Radius.zero,
  2. Radius end = Radius.zero,
})

Creates a horizontally symmetrical border radius where the start and end sides of the rectangle have the same radii.

Implementation

const BorderRadiusDirectional.horizontal({
  Radius start = Radius.zero,
  Radius end = Radius.zero,
}) : this.only(
       topStart: start,
       topEnd: end,
       bottomStart: start,
       bottomEnd: end,
     );