BoxDecoration class

Annotations
  • @immutable

Constructors

BoxDecoration({PdfColor? color, BoxBorder? border, BorderRadiusGeometry? borderRadius, List<BoxShadow>? boxShadow, Gradient? gradient, DecorationGraphic? image, BoxShape shape = BoxShape.rectangle})
const

Properties

border → BoxBorder?
final
borderRadius → BorderRadiusGeometry?
final
boxShadow → List<BoxShadow>?
final
color → PdfColor?
The color to fill in the background of the box.
final
gradient → Gradient?
final
hashCode → int
The hash code for this object.
no setterinherited
image → DecorationGraphic?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → BoxShape
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context, PdfRect box, [PaintPhase phase = PaintPhase.all]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited