DecorationImage class

Inheritance
Annotations
  • @immutable

Constructors

DecorationImage({required ImageProvider image, BoxFit fit = BoxFit.cover, Alignment alignment = Alignment.center, double? dpi})
const

Properties

alignment → Alignment
final
dpi → double?
final
fit → BoxFit
final
hashCode → int
The hash code for this object.
no setterinherited
image → ImageProvider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context, PdfRect box) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited