DecorationSvgImage class

Inheritance
Annotations
  • @immutable

Constructors

DecorationSvgImage({required String svg, BoxFit fit = BoxFit.cover, Alignment alignment = Alignment.center})
const

Properties

alignment → Alignment
final
fit → BoxFit
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
svg → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context, PdfRect box) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited