Document class
Constructors
- Document({PdfPageMode pageMode = PdfPageMode.none, DeflateCallback? deflate, bool compress = true, bool verbose = false, PdfVersion version = PdfVersion.pdf_1_5, ThemeData? theme, String? title, String? author, String? creator, String? subject, String? keywords, String? producer, XmlDocument? metadata})
- Document.load(PdfDocumentParserBase parser, {@Deprecated('Not used') PdfPageMode pageMode = PdfPageMode.none, DeflateCallback? deflate, bool compress = true, bool verbose = false, ThemeData? theme, String? title, String? author, String? creator, String? subject, String? keywords, String? producer})
Properties
- document → PdfDocument
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData?
-
final
Methods
-
addPage(
Page page, {int? index}) → void -
editPage(
int index, Page page) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
{bool enableEventLoopBalancing = false}) → Future< Uint8List> - Generates the PDF document as a memory file.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited