EdgeInsetsDirectional.fromSTEB constructor
Creates insets from offsets from the start, top, end, and bottom.
Implementation
const EdgeInsetsDirectional.fromSTEB(
this.start,
this.top,
this.end,
this.bottom,
);
Creates insets from offsets from the start, top, end, and bottom.
const EdgeInsetsDirectional.fromSTEB(
this.start,
this.top,
this.end,
this.bottom,
);