Flexible class

A widget that controls how a child of a Row, Column, or Flex flexes.

Inheritance
Implementers

Constructors

Flexible({int flex = 1, FlexFit fit = FlexFit.loose, required Widget child})

Properties

box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
canSpan → bool
no setterinherited
child → Widget?
finalinherited
fit → FlexFit
How a flexible child is inscribed into the available space.
final
flex → int
The flex factor to use for this child
final
hashCode → int
The hash code for this object.
no setterinherited
hasMoreWidgets → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
cloneContext() → WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
override
paintChild(Context context) → void
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() → WidgetContext
Get unmodified mutable context object
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited