GridPaper constructor

GridPaper({
  1. PdfColor color = lineColor,
  2. double interval = 100,
  3. int divisions = 5,
  4. int subdivisions = 2,
  5. Widget? child,
})

Creates a widget that draws a rectilinear grid lines.

Implementation

GridPaper({
  PdfColor color = lineColor,
  double interval = 100,
  int divisions = 5,
  int subdivisions = 2,
  Widget? child,
}) : assert(
       divisions > 0,
       'The "divisions" property must be greater than zero. If there were no divisions, the grid paper would not paint anything.',
     ),
     assert(
       subdivisions > 0,
       'The "subdivisions" property must be greater than zero. If there were no subdivisions, the grid paper would not paint anything.',
     ),
     horizontalColor = color,
     verticalColor = color,
     horizontalInterval = interval,
     verticalInterval = interval,
     horizontalDivisions = divisions,
     verticalDivisions = divisions,
     horizontalSubdivisions = subdivisions,
     verticalSubdivisions = subdivisions,
     margin = EdgeInsets.zero,
     horizontalOffset = 0,
     verticalOffset = 0,
     border = const Border(),
     scale = 1,
     opacity = 0.5,
     super(child: child);