copyWith method

IconThemeData copyWith({
  1. PdfColor? color,
  2. double? opacity,
  3. double? size,
  4. Font? font,
})

Creates a copy of this icon theme but with the given fields replaced with the new values.

Implementation

IconThemeData copyWith({
  PdfColor? color,
  double? opacity,
  double? size,
  Font? font,
}) {
  return IconThemeData(
    color: color ?? this.color,
    opacity: opacity ?? this.opacity,
    size: size ?? this.size,
    font: font ?? this.font,
  );
}