IntrinsicColumnWidth class

Inheritance

Constructors

IntrinsicColumnWidth({double? flex})
const

Properties

flex → double?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

layout(Widget child, Context context, BoxConstraints constraints) → ColumnLayout
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited