PageTheme class

Annotations
  • @immutable

Constructors

PageTheme({PdfPageFormat? pageFormat, BuildCallback? buildBackground, BuildCallback? buildForeground, ThemeData? theme, PageOrientation? orientation, EdgeInsetsGeometry? margin, bool clip = false, TextDirection? textDirection})
const

Properties

buildBackground → BuildCallback?
final
buildForeground → BuildCallback?
final
clip → bool
final
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsetsGeometry?
no setter
mustRotate → bool
no setter
orientation → PageOrientation
final
pageFormat → PdfPageFormat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection?
final
theme → ThemeData?
final

Methods

copyWith({PdfPageFormat? pageFormat, BuildCallback? buildBackground, BuildCallback? buildForeground, ThemeData? theme, PageOrientation? orientation, EdgeInsets? margin, bool? clip, TextDirection? textDirection}) → PageTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited