lineSplitter property
A custom function to split lines of text into words that may be wrapped
independently. When null (the default), lines are split at whitespace.
See LineSplitter for details and for an example enabling CJK wrapping.
Implementation
final LineSplitter? lineSplitter;