SizedBox.shrink constructor
SizedBox.shrink({
- Widget? child,
Creates a box that will become as small as its parent allows.
Implementation
SizedBox.shrink({this.child}) : width = 0.0, height = 0.0;
Creates a box that will become as small as its parent allows.
SizedBox.shrink({this.child}) : width = 0.0, height = 0.0;