Transform.rotateBox constructor

Transform.rotateBox({
  1. required double angle,
  2. Widget? child,
  3. bool unconstrained = false,
})

Creates a widget that transforms its child using a rotation around the center and relayout the bounding box.

Implementation

Transform.rotateBox({
  required double angle,
  Widget? child,
  this.unconstrained = false,
}) : transform = Matrix4.rotationZ(angle),
     adjustLayout = true,
     alignment = null,
     origin = null,
     super(child: child);