layout abstract method
First widget pass to calculate the children layout and bounding box
Implementation
void layout(
Context context,
BoxConstraints constraints, {
bool parentUsesSize = false,
});
First widget pass to calculate the children layout and bounding box
void layout(
Context context,
BoxConstraints constraints, {
bool parentUsesSize = false,
});